/**
 * gulpfile.free
 *
 * @author LeapIn Corp.
 * @since 1.6.10
 *
 * COMMAND LINE
 * gulp make [-p | --prd] - build wordpress theme zip file in /dist folder, add -p option to exclude files for development.
 *
 */

'use strict';
const config = require('./gulpconfig.json');

// include modules
const gulp = require('gulp');
const minifyCSS = require('gulp-minify-css');
const uglify = require('gulp-uglify');
const concat = require("gulp-concat");
const zip = require('gulp-zip');
const ignore = require('gulp-ignore');
const minimist = require('minimist');
const gutil = require('gulp-util');

// get variable from command line
const options = minimist(process.argv.slice(2), config.args);
const prd = options.prd;

// minify JS
gulp.task('minify-js', function () {
    return gulp.src('./library/js/src/**/*.js')
        .pipe(uglify())
        .on('error', function (err) {
            gutil.log(gutil.colors.red('[Error]'), err.toString());
        })
        .pipe(gulp.dest('./library/js/\.tmp'));
});

// minify css
gulp.task('minify-css', [], function () {
    return gulp.src('./library/css/src/**/*.css')
        .pipe(minifyCSS())
        .pipe(gulp.dest('./library/css/dist'));
});

// make js bundle for PRD
gulp.task('make-bundle-js', ['minify-js'], function () {
    var files = config.free.bundle_files;
    return gulp.src(files)
        .pipe(concat(config.concat_js))
        .pipe(gulp.dest(config.dest.js));
});

// make js for PRD
gulp.task('make-js', ['make-bundle-js'], function () {
    var files = [
        './library/js/\.tmp/libs/alpha-color-picker.js',
        './library/js/\.tmp/libs/alpha-color-picker-admin.js',
        './library/js/\.tmp/libs/loadCSS.js',
        './library/js/\.tmp/above-the-fold.js',
        './library/js/\.tmp/admin.js'
    ];
    return gulp.src(files, {base: './library/js/\.tmp/'})
        .pipe(gulp.dest('./library/js/dist'));
});

// make js and css for PRD
gulp.task('make-js-css', ['make-js', 'minify-css']);

// make theme zip.
gulp.task('make', ['make-js-css'], function () {
    var files = config.free.zip_includes;
    files = prd ? files.concat(config.zip_excludes_for_prd) : files;

    return gulp.src(files, {base: '.'})
        .pipe(ignore.include({isFile: true}))
        .pipe(zip(config.zip_file))
        .pipe(gulp.dest(config.paths.dest));
});

// default task
gulp.task('default', ['make']);
