<?php
/**
 * amp.php
 *
 * @author LeapIn Corp.
 * @since 1.0.0
 */
class LEAPIN_AMP_Tags
{
    /**
     * Judge if it's in ajax page.
     */
    public static function is_amp()
    {
        if (function_exists('bbp_is_topic')) {
            if (bbp_is_topic()) {
                return false;
            }
        }
        $is_amp = false;
        if (empty($_GET['amp'])) {
            return false;
        }

        if (self::is_amp_active() &&
            is_singular() &&
            $_GET['amp'] === '1' &&
            self::has_amp_page()
        ) {
            $is_amp = true;
        }
        return $is_amp;
    }

    /**
     * Convert content to amp content
     */
    public static function convert_content_for_amp($the_content)
    {
        if (!self::is_amp()) {
            return $the_content;
        }


        $amp_placeholder = '<amp-img layout="fill" src="' . get_template_directory_uri() . '/images/transparence.png' . '" placeholder>';

        // remove noscript tag
        $the_content = preg_replace('/<noscript>/i', '', $the_content);
        $the_content = preg_replace('/<\/noscript>/i', '', $the_content);

        //remove font tag
        $the_content = preg_replace('/<font[^>]*?>/i', '', $the_content);
        $the_content = preg_replace('/<\/font>/i', '', $the_content);

        //remove style tag
        $the_content = preg_replace('/<style[^>]*?>/i', '', $the_content);
        $the_content = preg_replace('/<\/style>/i', '', $the_content);

        // http => https (Amazon)
        $the_content = str_replace('http://rcm-jp.amazon.co.jp/', 'https://rcm-fe.amazon-adsystem.com/', $the_content);
        $the_content = str_replace('"//rcm-fe.amazon-adsystem.com/', '"https://rcm-fe.amazon-adsystem.com/', $the_content);
        $the_content = str_replace("'//rcm-fe.amazon-adsystem.com/", "'https://rcm-fe.amazon-adsystem.com/", $the_content);
        $the_content = str_replace('http://ecx.images-amazon.com', 'https://images-fe.ssl-images-amazon.com', $the_content);
        // http => https (Rakten)
        $the_content = str_replace('http://thumbnail.image.rakuten.co.jp', 'https://thumbnail.image.rakuten.co.jp', $the_content);

        //replace embedded Amazon tag
        $pattern = '/<iframe([^>]+?)(src="https?:\/\/rcm-fe.amazon-adsystem.com\/[^"]+?t=([^&"]+)[^"]+?asins=([^&"]+)[^"]*?").*?><\/iframe>/is';
        $amazon_url = 'https://www.amazon.co.jp/exec/obidos/ASIN/$4/$3/ref=nosim/';
        $append = PHP_EOL . '<amp-iframe$1$2 width="120" height="240" frameborder="0">' . $amp_placeholder . '</amp-iframe><br><a href="' . $amazon_url . '" class="aa-link"></a>' . PHP_EOL;

        // http => https (YouTube)
        $the_content = str_replace('http://www.youtube.com/', 'https://www.youtube.com/', $the_content);

        $the_content = preg_replace($pattern, $append, $the_content);

        // C2A0 => space
        $the_content = str_replace('\xc2\xa0', ' ', $the_content);

        // remove style attribute
        $the_content = preg_replace('/ *?style=["][^"]*?["]/i', '', $the_content);
        $the_content = preg_replace('/ *?style=[\'][^\']*?[\']/i', '', $the_content);

        // remove target attribute
        $the_content = preg_replace('/ *?target=["][^"]*?["]/i', '', $the_content);
        $the_content = preg_replace('/ *?target=[\'][^\']*?[\']/i', '', $the_content);

        // remove onclick attribute
        $the_content = preg_replace('/ *?onclick=["][^"]*?["]/i', '', $the_content);
        $the_content = preg_replace('/ *?onclick=[\'][^\']*?[\']/i', '', $the_content);

        // remove onload attribute
        $the_content = preg_replace('/ *?onload=["][^"]*?["]/i', '', $the_content);
        $the_content = preg_replace('/ *?onload=[\'][^\']*?[\']/i', '', $the_content);

        // remove marginwidth attribute
        $the_content = preg_replace('/ *?marginwidth=["][^"]*?["]/i', '', $the_content);
        $the_content = preg_replace('/ *?marginwidth=[\'][^\']*?[\']/i', '', $the_content);

        // remove marginheight attribute
        $the_content = preg_replace('/ *? marginheight=["][^"]*?["]/i', '', $the_content);
        $the_content = preg_replace('/ *? marginheight=[\'][^\']*?[\']/i', '', $the_content);

        // remove type attribute(YouTube)
        $the_content = str_replace(" class='youtube-player' type='text/html'", " class='youtube-player'", $the_content);
        $the_content = str_replace(' class="youtube-player" type="text/html"', ' class="youtube-player"', $the_content);

        // site icon optimization
        $the_content = preg_replace('/<img([^>]+?src="[^"]+?(mzstatic\.com|phobos\.apple\.com|googleusercontent\.com|ggpht\.com)[^"]+?[^>\/]+)\/?>/is', '<amp-img$1 width="75" height="75" sizes="(max-width: 75px) 100vw, 75px"></amp-img>', $the_content);
        $the_content = preg_replace('/<img([^>]+?src="[^"]+?nabettu\.github\.io[^"]+?[^>\/]+)\/?>/is', '<amp-img$1 width="120" height="36" sizes="(max-width: 120px) 100vw, 120px"></amp-img>', $the_content);

        // img => amp-img
        $res = preg_match_all('/<img(.+?)\/?>/is', $the_content, $m);
        if ($res) {

            foreach ($m[0] as $match) {
                //変数の初期化
                $src_attr = null;
                $url = null;
                $width_attr = null;
                $width_value = null;
                $height_attr = null;
                $height_value = null;
                $alt_attr = null;
                $alt_value = null;
                $title_attr = null;
                $title_value = null;
                $sizes_attr = null;
                $responsive = null;
                $class_attr = null;

                // src
                $src_res = preg_match('/src=["\']([^"\']+?)["\']/is', $match, $srcs);
                if ($src_res) {
                    $src_attr = ' ' . $srcs[0];
                    $url = $srcs[1];
                }

                // width
                $width_res = preg_match('/width=["\']([^"\']*?)["\']/is', $match, $widths);
                if ($width_res) {
                    $width_attr = ' ' . $widths[0];
                    $width_value = $widths[1];
                }

                // height
                $height_res = preg_match('/height=["\']([^"\']*?)["\']/is', $match, $heights);
                if ($height_res) {
                    $height_attr = ' ' . $heights[0];
                    $height_value = $heights[1];
                }

                // alt
                $alt_res = preg_match('/alt=["]([^"]*?)["]/is', $match, $alts);
                if (!$alt_res)
                    $alt_res = preg_match("/alt=[']([^']*?)[']/is", $match, $alts);
                if ($alt_res) {
                    $alt_attr = ' ' . $alts[0];
                    $alt_value = $alts[1];
                }

                // title
                $title_res = preg_match('/title=["]([^"]*?)["]/is', $match, $titles);
                if (!$title_res)
                    $title_res = preg_match("/title=[']([^']*?)[']/is", $match, $titles);
                if ($title_res) {
                    $title_attr = ' ' . $titles[0];
                    $title_value = $titles[1];
                }

                // class
                $class_res = preg_match('/class=["]([^"]*?)["]/is', $match, $classes);
                if (!$class_res)
                    $class_res = preg_match("/class=[']([^']*?)[']/is", $match, $classes);
                if ($class_res) {
                    $class_attr = ' ' . $classes[0];
                    $class_value = $classes[1];
                }

                // get width and height if it's not set in tag
                if ($url && (empty($width_value) || empty($height_value))) {
                    $size = leapin_get_image_width_and_height($url);
                    if ($size && $size['width'] > 700) {
                        $class_attr = str_replace('class="', 'class="internal-content-img ', $class_attr);
                        $width_value = $size['width'];
                        $width_attr = ' width="' . $width_value . '"';
                        $height_value = $size['height'];
                        $height_attr = ' height="' . $height_value . '"';
                    } else {
                        // in case external img src
                        $class_attr = str_replace('class="', 'class="external-content-img ', $class_attr);
                        if (
                            strpos($url, '//images-fe.ssl-images-amazon.com') !== false ||
                            strpos($url, '//thumbnail.image.rakuten.co.jp') !== false ||
                            strpos($url, '//item.shopping.c.yimg.jp') !== false
                        ) {
                            // specific site images
                            $width_value = 75;
                            $width_attr = ' width="75"';
                            $height_value = 75;
                            $height_attr = ' height="75"';
                        } else {
                            // others
                            $width_value = 300;
                            $width_attr = ' width="300"';
                            $height_value = 300;
                            $height_attr = ' height="300"';
                        }

                    }
                }

                //specific img
                if (preg_match('/class=["\']author__img-lg["\']/is', $match)) {
                    $width_value = 100;
                    $width_attr = ' width="100"';
                    $height_value = 100;
                    $height_attr = ' height="100"';
                } elseif (preg_match('/class=["\']author__img-sm["\']/is', $match)) {
                    $width_value = 30;
                    $width_attr = ' width="30"';
                    $height_value = 30;
                    $height_attr = ' height="30"';
                }

                //sizes attribute
                if ($width_value) {
                    $sizes_attr = ' sizes="(max-width: ' . $width_value . 'px) 100vw, ' . $width_value . 'px"';
                }
                //set amp-img tag
                if ($responsive) {
                    $tag = '<amp-img' . $src_attr . ' width="16" height="16" layout="responsive"' . '></amp-img>';
                } else {
                    $tag = '<amp-img' . ' layout="responsive" ' . $src_attr . $width_attr . $height_attr . $alt_attr . $title_attr . $sizes_attr . $class_attr . '></amp-img>';
                }

                //img => amp-img
                $the_content = preg_replace('{' . preg_quote($match) . '}', $tag, $the_content, 1);
            }
        }


        // img => amp
        $the_content = preg_replace('/<img(.+?)\/?>/is', '<amp-img$1></amp-img>', $the_content);

        // twitter => amp-twitter
        $pattern = '/<blockquote class="twitter-tweet".*?>.+?<a href="https:\/\/twitter.com\/.*?\/status\/(.*?)">.+?<\/blockquote>/is';
        $append = '<p><amp-twitter width=592 height=472 layout="responsive" data-tweetid="$1"></amp-twitter></p>';
        $the_content = preg_replace($pattern, $append, $the_content);

        // facebook => amp-facebook
        $pattern = '/<fb:post href="([^"]+?)"><\/fb:post>/is';
        $append = '<amp-facebook width=324 height=438 layout="responsive" data-href="$1"></amp-facebook>';
        $the_content = preg_replace($pattern, $append, $the_content);

        // vine => amp-vine
        $pattern = '/<iframe[^>]+?src="https:\/\/vine.co\/v\/(.+?)\/embed\/simple".+?><\/iframe>/is';
        $append = '<p><amp-vine data-vineid="$1" width="592" height="592" layout="responsive"></amp-vine></p>';
        $the_content = preg_replace($pattern, $append, $the_content);

        // Instagram => amp-instagram
        $pattern = '/<blockquote class="instagram-media".+?"https:\/\/www.instagram.com\/p\/(.+?)\/".+?<\/blockquote>/is';
        $append = '<p><amp-instagram layout="responsive" data-shortcode="$1" width="592" height="592" ></amp-instagram></p>';
        $the_content = preg_replace($pattern, $append, $the_content);

        // YouTube => amp-youtube
        $pattern = '/<iframe[^>]+?src="https?:\/\/www.youtube.com\/embed\/([^\?"]+).*?".*?><\/iframe>/is';
        $append = '<amp-youtube layout="responsive" data-videoid="$1" width="800" height="450"></amp-youtube>';
        $the_content = preg_replace($pattern, $append, $the_content);

        // Facebook Video => fb-video
        $pattern = '/<div class="fb-video" data-allowfullscreen="true" data-href="([^"]+?)"><\/div>/is';
        $append = '<amp-facebook layout="responsive" data-href="$1" width="500" height="450"></amp-facebook>';
        $the_content = preg_replace($pattern, $append, $the_content);

        // For iframe
        $the_content = preg_replace('/ +allowTransparency(=["\'][^"\']*?["\'])?/i', '', $the_content);
        $the_content = preg_replace('/ +allowFullScreen(=["\'][^"\']*?["\'])?/i', '', $the_content);
        $the_content = preg_replace('/ +webkitAllowFullScreen(=["\'][^"\']*?["\'])?/i', '', $the_content);
        $the_content = preg_replace('/ +mozallowfullscreen(=["\'][^"\']*?["\'])?/i', '', $the_content);

        // iframe => a tag
        $pattern = '/<iframe[^>]+?src="(http:\/\/[^"]+?)"[^>]+?title="([^"]+?)"[^>]+?><\/iframe>/is';
        $append = '<a href="$1">$2</a>';
        $the_content = preg_replace($pattern, $append, $the_content);
        $pattern = '/<iframe[^>]+?title="([^"]+?)[^>]+?src="(http:\/\/[^"]+?)""[^>]+?><\/iframe>/is';
        $append = '<a href="$1">$2</a>';
        $the_content = preg_replace($pattern, $append, $the_content);
        // iframe => a tag
        $pattern = '/<iframe[^>]+?src="(http:\/\/[^"]+?)"[^>]+?><\/iframe>/is';
        $append = '<a href="$1">$1</a>';
        $the_content = preg_replace($pattern, $append, $the_content);

        //iframe => amp-iframe
        $pattern = '/<iframe/i';
        $append = '<amp-iframe layout="responsive" sandbox="allow-scripts allow-same-origin allow-popups"';
        $the_content = preg_replace($pattern, $append, $the_content);
        $pattern = '/<\/iframe>/i';
        $append = $amp_placeholder . '</amp-iframe>';
        $the_content = preg_replace($pattern, $append, $the_content);

        //iframe => amp-iframe
        $pattern = '/<iframe/i';
        $append = '<amp-iframe layout="responsive" sandbox="allow-scripts allow-same-origin allow-popups"';
        $the_content = preg_replace($pattern, $append, $the_content);
        $pattern = '/<\/iframe>/i';
        $append = $amp_placeholder . '</amp-iframe>';
        $the_content = preg_replace($pattern, $append, $the_content);

        // remove script
        $pattern = '/<p><script.+?<\/script><\/p>/i';
        $append = '';
        $the_content = preg_replace($pattern, $append, $the_content);
        $pattern = '/<script.+?<\/script>/is';
        $append = '';
        $the_content = preg_replace($pattern, $append, $the_content);

        // remove empty amp-img
        $pattern = '{<amp-img></amp-img>}i';
        $append = '';
        $the_content = preg_replace($pattern, $append, $the_content);


        // remove p tag
        $pattern = '{<p></p>}i';
        $append = '';
        $the_content = preg_replace($pattern, $append, $the_content);

        return $the_content;
    }


    /**
     * Convert content to AMP
     */
    public static function get_template_part_amp($template_name)
    {
        ob_start();
        get_template_part($template_name);
        $template = ob_get_clean();
        $template = self::convert_content_for_amp($template);
        echo $template;
    }

    /**
     * Get AMP AdSense Code
     */
    public static function generate_amp_adsense_code()
    {
        $adsense_code = null;
        if (self::get_amp_adsense_code() || is_active_sidebar('adsense-300')) {
            $ad300 = self::get_amp_adsense_code();
            ob_start();
            dynamic_sidebar('adsense-300');
            $ad300 .= ob_get_clean();
            preg_match('/data-ad-client="(ca-pub-[^"]+?)"/i', $ad300, $m);
            if (empty($m[1])) return;
            $data_ad_client = $m[1];
            if (!$data_ad_client) return;
            preg_match('/data-ad-slot="([^"]+?)"/i', $ad300, $m);
            $data_ad_slot = $m[1];
            if (!$data_ad_slot) return;
            $adsense_code = '<amp-ad width="300" height="250" type="adsense" data-ad-client="' . $data_ad_client . '" data-ad-slot="' . $data_ad_slot . '"></amp-ad>';
        }
        return $adsense_code;
    }

    /**
     * Get AMP URL
     *
     * @return string
     */
    public static function get_amp_permalink()
    {
        $permalink = leapin_get_permalink();
        if (strpos($permalink, '?') !== false) {
            $amp_permalink = $permalink . '&amp;amp=1';
        } else {
            $amp_permalink = $permalink . '?amp=1';
        }
        return $amp_permalink;
    }

    /**
     * Deactivate Crayon Syntax Highlighter in AMP
     */
    public static function remove_crayon_syntax_highlighter()
    {
        if (isset($_GET['amp']) && $_GET['amp'] === '1') {
            //Crayon Syntax HighlighterはAMPページで適用しない
            remove_filter('the_posts', 'CrayonWP::the_posts', 100);
        }
    }

    public static function is_amp_active()
    {
        $inst = LEAPIN_Theme_Mod::get_instance();
        $entire = $inst->get(LEAPIN_IDs::$leapin_amp_active);
        $exclude_category_ids = $inst->get(LEAPIN_IDs::$leapin_amp_no_category_ids, '');
        $exclude_category_ids = explode(',', $exclude_category_ids);
        $category = false;
        if(!in_category( $exclude_category_ids )){
            $category = true;
        }
        $single = self::is_amp_page_enable();

        return $entire && $category && $single;
    }

    private static function is_amp_page_enable()
    {
        return !get_post_meta(get_the_ID(), 'is_noamp', true);
    }

    private static function is_amp_format(){
        $rtn = false;
        $format = get_post_format()?:'standard';
        $amp_format = ['standard'];
        if(isset($format) && in_array($format, $amp_format)){
            $rtn = true;
        }

        return $rtn;
    }

    public static function has_amp_page(){
        return self::is_amp_active() &&
            is_singular() &&
            self::is_amp_format() &&
            !is_home() &&
            !is_front_page() &&
            (!function_exists('is_bbpress') || !is_bbpress());
    }

    public static function get_amp_test_tool_url($url){
        $test_url = null;
        $encoded_url = str_replace('&amp;', '&', $url);
        $encoded_url = urlencode($encoded_url);
        $test_url = 'https://search.google.com/test/amp?url='.$encoded_url;
        return $test_url;
    }

    public static function get_icomoon_font_face()
    {
        $template_directory_uri = get_template_directory_uri();
        ob_start();
        ?>
        @font-face {
        font-family: "icomoon";
        src: url("<?php echo $template_directory_uri; ?>/library/fonts/icomoon/icomoon.eot");
        src: url("<?php echo $template_directory_uri; ?>/library/fonts/icomoon/icomoon.eot#iefix") format("embedded-opentype"),
        url("<?php echo $template_directory_uri; ?>/library/fonts/icomoon/icomoon.ttf") format("truetype"),
        url("<?php echo $template_directory_uri; ?>/library/fonts/icomoon/icomoon.woff") format("woff"),
        url("<?php echo $template_directory_uri; ?>/library/fonts/icomoon/icomoon.svg#icomoon") format("svg");
        font-weight: normal;
        font-style: normal;
        }
        <?php

        return trim(ob_get_clean());
    }
//    function is_ads_visible(){
//        $article_ids = get_exclude_article_ids();
//        $category_ids =get_exclude_category_ids();
//
//        // exclude ads
//        $is_exclude_ids = (
//            is_single( $article_ids ) ||
//            is_page( $article_ids ) ||
//            (is_single() && in_category( $category_ids ) ) ||
//            is_category( $category_ids )
//        );
//        return get_theme_mod( 'ads_visible', true ) &&
//            !$is_exclude_ids &&
//            !is_ads_removed_in_page() &&
//            !is_attachment() &&
//            !is_search();
//    }

//    function is_ads_removed_in_page(){
//        return get_post_meta(get_the_ID(), 'is_ads_removed_in_page', true);
//    }

}
add_filter('the_content', 'LEAPIN_AMP_Tags::convert_content_for_amp', 999999999);
add_action('wp_loaded', 'LEAPIN_AMP_Tags::remove_crayon_syntax_highlighter');