<?php
/**
 * Footer Widget Setting
 *
 * @author LeapIn Corp.
 * @since 1.0.0
 */

$panel = 'leapin_settings';
$section = 'leapin_footer_widgets';

$wp_customize->add_section($section_id = $section, array(
    'title' => __('Footer', 'pjax-blog'),
    'panel' => $panel,
    'description' => '<em>' . __('Configure the widgets that are shown in the footer section of your website', 'pjax-blog') . '</em>', // Include html tags such as <p>.
    'priority' => 60, // Mixed with top-level-section hierarchy.
));

/**
 * Footer Background Image
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_footer_bg_image, array(
    'type' => 'theme_mod',
    'capability' => 'manage_options',
    'transport' => LEAPIN_IDs::$refresh,
    'sanitize_callback' => 'esc_url_raw',
));

$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, LEAPIN_IDs::$leapin_footer_bg_image,
    array(
        'label' => __('Footer Background Image', 'pjax-blog'),
        'section' => $section,
        'settings' => LEAPIN_IDs::$leapin_footer_bg_image
    )
));

$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_footer_widget_heading, array(
    'type' => 'theme_mod', // or 'option'
    'sanitize_callback' => 'leapin_sanitize_mock',
));
$wp_customize->add_control(new LEAPIN_Heading_Customize_Control($wp_customize, LEAPIN_IDs::$leapin_footer_widget_heading, array(
    'settings' => LEAPIN_IDs::$leapin_footer_widget_heading,
    'label' => __('Footer Widgets Area', 'pjax-blog'),
    'section' => $section,
)));
/**
 * @FooterWidget Columns
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_footer_widget_columns, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => LEAPIN_Theme_Mod::$default_leapin_footer_widget_columns,
    'transport' => LEAPIN_IDs::$refresh,
    'sanitize_callback' => 'leapin_sanitize_text'
));

$wp_customize->add_control(LEAPIN_IDs::$leapin_footer_widget_columns, array(
    'label' => __('Columns', 'pjax-blog'),
    'type' => 'radio',
    'section' => $section,
    'choices' => LEAPIN_Theme_Mod::$choice_leapin_footer_widget_columns
));

/**
 * @FooterWidget Spec
 * Foreground
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_footer_widget_color, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => '',
    'transport' => LEAPIN_IDs::$postMessage,
    'sanitize_callback' => 'leapin_sanitize_rgba_color'
));
$wp_customize->add_control(new LEAPIN_Customize_Alpha_Color_Control($wp_customize, LEAPIN_IDs::$leapin_footer_widget_color . '_control', array(
    'label' => __('Font Color', 'pjax-blog'),
    'section' => $section,
    'settings' => LEAPIN_IDs::$leapin_footer_widget_color,
    'show_opacity' => true,
)));

/**
 * title color
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_footer_widget_title_color, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => '',
    'transport' => LEAPIN_IDs::$postMessage,
    'sanitize_callback' => 'leapin_sanitize_rgba_color'
));
$wp_customize->add_control(new LEAPIN_Customize_Alpha_Color_Control($wp_customize, LEAPIN_IDs::$leapin_footer_widget_title_color . '_control', array(
    'label' => __('Title Color', 'pjax-blog'),
    'section' => $section,
    'settings' => LEAPIN_IDs::$leapin_footer_widget_title_color,
    'show_opacity' => true,
)));

/**
 * @FooterWidget Spec
 * Background
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_footer_widget_background, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => '',
    'transport' => LEAPIN_IDs::$postMessage,
    'sanitize_callback' => 'leapin_sanitize_rgba_color'
));
$wp_customize->add_control(new LEAPIN_Customize_Alpha_Color_Control($wp_customize, LEAPIN_IDs::$leapin_footer_widget_background, array(
    'label' => __('Background', 'pjax-blog'),
    'section' => $section,
    'settings' => LEAPIN_IDs::$leapin_footer_widget_background,
    'show_opacity' => true,
)));

/**
 * @FooterWidget Spec
 * Footer Border Color
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_footer_widget_border_color, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => '',
    'transport' => LEAPIN_IDs::$postMessage,
    'sanitize_callback' => 'leapin_sanitize_rgba_color'
));
$wp_customize->add_control(new LEAPIN_Customize_Alpha_Color_Control($wp_customize, LEAPIN_IDs::$leapin_footer_widget_border_color, array(
    'label' => __('Border Color', 'pjax-blog'),
    'section' => $section,
    'settings' => LEAPIN_IDs::$leapin_footer_widget_border_color,
    'show_opacity' => true,
)));

/**
 * @FooterWidget Spec
 * Footer Links
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_footer_widget_color_links, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => '',
    'transport' => LEAPIN_IDs::$postMessage,
    'sanitize_callback' => 'leapin_sanitize_rgba_color'
));
$wp_customize->add_control(new LEAPIN_Customize_Alpha_Color_Control($wp_customize, LEAPIN_IDs::$leapin_footer_widget_color_links, array(
    'label' => __('Links', 'pjax-blog'),
    'section' => $section,
    'settings' => LEAPIN_IDs::$leapin_footer_widget_color_links,
    'show_opacity' => true,
)));

/**
 * @FooterWidget Spec
 * Footer Links Hover
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_footer_widget_color_links_hover, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => '',
    'transport' => LEAPIN_IDs::$refresh,
    'sanitize_callback' => 'leapin_sanitize_rgba_color'
));
$wp_customize->add_control(new LEAPIN_Customize_Alpha_Color_Control($wp_customize, LEAPIN_IDs::$leapin_footer_widget_color_links_hover, array(
    'label' => __('Links Hover Color', 'pjax-blog'),
    'section' => $section,
    'settings' => LEAPIN_IDs::$leapin_footer_widget_color_links_hover,
    'show_opacity' => true,
)));

$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_footer_copyright_heading, array(
    'type' => 'theme_mod', // or 'option'
    'sanitize_callback' => 'leapin_sanitize_mock',
));
$wp_customize->add_control(new LEAPIN_Heading_Customize_Control($wp_customize, LEAPIN_IDs::$leapin_footer_copyright_heading, array(
    'settings' => LEAPIN_IDs::$leapin_footer_copyright_heading,
    'label' => __('Footer Copyright Area', 'pjax-blog'),
    'section' => $section,
)));

$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_copyright_color, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => '',
    'transport' => LEAPIN_IDs::$postMessage,
    'sanitize_callback' => 'leapin_sanitize_rgba_color'
));
$wp_customize->add_control(new LEAPIN_Customize_Alpha_Color_Control($wp_customize, LEAPIN_IDs::$leapin_copyright_color, array(
    'label' => __('Font Color', 'pjax-blog'),
    'section' => $section,
    'settings' => LEAPIN_IDs::$leapin_copyright_color,
    'show_opacity' => true,
)));

/**
 * @Footer Spec
 * Background
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_copyright_background, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => '',
    'transport' => LEAPIN_IDs::$postMessage,
    'sanitize_callback' => 'leapin_sanitize_rgba_color'
));
$wp_customize->add_control(new LEAPIN_Customize_Alpha_Color_Control($wp_customize, LEAPIN_IDs::$leapin_copyright_background, array(
    'label' => __('Background', 'pjax-blog'),
    'section' => $section,
    'settings' => LEAPIN_IDs::$leapin_copyright_background,
    'show_opacity' => true,
)));

/**
 * @Footer Spec
 * Links
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_copyright_links, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => '',
    'transport' => LEAPIN_IDs::$postMessage,
    'sanitize_callback' => 'leapin_sanitize_rgba_color'
));
$wp_customize->add_control(new LEAPIN_Customize_Alpha_Color_Control($wp_customize, LEAPIN_IDs::$leapin_copyright_links, array(
    'label' => __('Links', 'pjax-blog'),
    'section' => $section,
    'settings' => LEAPIN_IDs::$leapin_copyright_links,
    'show_opacity' => true,
)));

/**
 * @Footer Spec
 * Links:Hover
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_copyright_links_hover, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => '',
    'transport' => LEAPIN_IDs::$refresh,
    'sanitize_callback' => 'leapin_sanitize_rgba_color'
));
$wp_customize->add_control(new LEAPIN_Customize_Alpha_Color_Control($wp_customize, LEAPIN_IDs::$leapin_copyright_links_hover, array(
    'label' => __('Links Hover Color', 'pjax-blog'),
    'section' => $section,
    'settings' => LEAPIN_IDs::$leapin_copyright_links_hover,
    'show_opacity' => true,
)));


/**
 * Footer Copyright Text
 */

$wp_customize->add_setting(
    $setting_id = LEAPIN_IDs::$leapin_copyright_text, array(
        'type' => 'theme_mod', // or 'option'
        'capability' => 'manage_options',
        'default' => LEAPIN_Theme_Mod::$default_leapin_copyright_text,
        'transport' => LEAPIN_IDs::$refresh,
        'sanitize_callback' => 'sanitize_textarea_field'
    )
);

$wp_customize->add_control(LEAPIN_IDs::$leapin_copyright_text,
    array(
        'label' => __('Copyright Text', 'pjax-blog'),
        'section' => $section,
        'type' => 'textarea',
        'description' => __('Enter the copyright text that can be found in your site\'s footer. You can also add html tags.', 'pjax-blog')
    )
);
