<?php
/**
 * Pjax Options
 *
 * @author LeapIn Corp.
 * @since 1.0.0
 */


/**
 * Heading Fonts.
 */
// Load the file that implements 'leapin_get_pjax_transitions' function.
require_once get_template_directory() . '/inc/general-settings/pjax/transition-library.php';
$transitions = leapin_get_pjax_transitions();

$panel = 'leapin_settings';
$section = 'leapin_pjax_section';
LEAPIN_IDs::initPriority();

$wp_customize->add_section(
    $section_id = $section,
    array(
        'title' => __('Pjax', 'pjax-blog'),
        'description' => '<em>' . __('Select desired Pjax Transition combination for your website.', 'pjax-blog') . '</em>',
        'panel' => $panel,
        'priority' => 70,
    )
);

/**
 * Enable Pjax transition
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_pjax_enable, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => true,
    'transport' => LEAPIN_IDs::$refresh,
    'sanitize_callback' => 'leapin_sanitize_checkbox'
));

$wp_customize->add_control(LEAPIN_IDs::$leapin_pjax_enable, array(
    'type' => 'checkbox',
    'label' => __('Activate Pjax', 'pjax-blog'),
    'section' => $section,
    'description' => __('This option applies for Activation of Pjax Page Transition', 'pjax-blog'),
    'priority' => LEAPIN_IDs::getPriority()
));

/**
 * Minimum Window Size for Activation
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_pjax_min_window_size, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'transport' => LEAPIN_IDs::$refresh,
    'default' => LEAPIN_Theme_Mod::$default_leapin_min_window_size,
    'sanitize_callback' => 'leapin_sanitize_number',
));
$wp_customize->add_control(LEAPIN_IDs::$leapin_pjax_min_window_size, array(
    'label' => __('Minimum Window Width for Activation(px)', 'pjax-blog'),
    'section' => $section,
    'type' => 'text',
    'description' => __('Activate Pjax transition when the window size is wider than(>=):', 'pjax-blog'),
    'priority' => LEAPIN_IDs::getPriority()
));

/**
 * Select transition type
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_pjax_transition,
    array(
        'type' => 'theme_mod', // or 'option'
        'capability' => 'manage_options',
        'default' => LEAPIN_Theme_Mod::$default_leapin_pjax_transition,
        'transport' => LEAPIN_IDs::$refresh,
        'sanitize_callback' => 'leapin_sanitize_text'
    )
);

$wp_customize->add_control(LEAPIN_IDs::$leapin_pjax_transition,
    array(
        'label' => __('Transition', 'pjax-blog'),
        'type' => 'select',
        'description' => sprintf(__('Select the desired Page Transition to be applied. <a href=%s target="_blank">See Demos</a>', 'pjax-blog'), esc_url('https://demo.leap-in.com/pjax-blog-1/555')),
        'section' => $section,
        'choices' => $transitions,
        'priority' => LEAPIN_IDs::getPriority()
    )
);

/**
 * Random Transition
 */
//$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_pjax_random_transition, array(
//    'type' => 'theme_mod', // or 'option'
//    'capability' => 'manage_options',
//    'transport' => LEAPIN_IDs::$refresh,
//    'sanitize_callback' => 'leapin_sanitize_checkbox'
//));
//
//$wp_customize->add_control(LEAPIN_IDs::$leapin_pjax_random_transition, array(
//    'type' => 'checkbox',
//    'label' => __('Activate Random Transition', 'pjax-blog'),
//    'section' => $section,
//    'description' => __('Transition selected above is ignored if it\'s checked.', 'pjax-blog'),
//    'priority' => LEAPIN_IDs::getPriority()
//));

/**
 * Background Color of page transition
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_pjax_transition_bg_color, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => '',
    'transport' => LEAPIN_IDs::$postMessage,
    'sanitize_callback' => 'leapin_sanitize_rgba_color'
));
$wp_customize->add_control(new LEAPIN_Customize_Alpha_Color_Control($wp_customize, LEAPIN_IDs::$leapin_pjax_transition_bg_color, array(
    'label' => __('Background Color while Page Transition', 'pjax-blog'),
    'section' => $section,
    'settings' => LEAPIN_IDs::$leapin_pjax_transition_bg_color,
    'show_opacity' => true,
    'priority' => LEAPIN_IDs::getPriority()
)));

/**
 * Overlay Color of page transition
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_pjax_transition_overlay_color, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => '',
    'transport' => LEAPIN_IDs::$postMessage,
    'sanitize_callback' => 'leapin_sanitize_rgba_color'
));
$wp_customize->add_control(new LEAPIN_Customize_Alpha_Color_Control($wp_customize, LEAPIN_IDs::$leapin_pjax_transition_overlay_color, array(
    'label' => __('Overlay Color while Page Transition', 'pjax-blog'),
    'section' => $section,
    'settings' => LEAPIN_IDs::$leapin_pjax_transition_overlay_color,
    'show_opacity' => true,
    'priority' => LEAPIN_IDs::getPriority()
)));

/**
 * Loading Circle Color of page transition
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_pjax_transition_loading_color, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => '',
    'transport' => LEAPIN_IDs::$refresh,
    'sanitize_callback' => 'sanitize_hex_color'
));
$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, LEAPIN_IDs::$leapin_pjax_transition_loading_color, array(
    'label' => __('Loading Circle Color while Page Transition', 'pjax-blog'),
    'section' => $section,
    'settings' => LEAPIN_IDs::$leapin_pjax_transition_loading_color,
    'priority' => LEAPIN_IDs::getPriority()
)));

