<?php
/**
 * Class LEAPIN_Navigation
 *
 * generate custom menu
 *
 * @author LeapIn Corp.
 * @since 1.0.0
 */
class LEAPIN_Navigation
{

    private static $menu_name = '';

    public static function the_menu($menu_name, $limit = 3, $footer = false)
    {

        self::$menu_name = $menu_name;
        /* create multilevel menu structure array */
        $multi_menu_items = [];

        if (($locations = get_nav_menu_locations())
            && isset($locations[$menu_name])) {

            // get menu items
            $menu_items = wp_get_nav_menu_items($locations[$menu_name]);

            if ($menu_items) :

                foreach ($menu_items as $menu) : setup_postdata($menu);
                    self::create_menu_structure($multi_menu_items, $menu);

                endforeach;

                wp_reset_postdata();
            endif;
        }
        /* end create multilevel menu structure array */

        /* echo multilevel menu */
        $echo = '';
        $echo = self::get_menu_tag($echo, $footer, $multi_menu_items, $limit);

        echo $echo;
    }

    private static function get_menu_tag(&$echo, $footer, $multi_menu_items, $limit, $level = 0)
    {

        if ($level >= $limit) {
            return $echo;
        }
        global $leapin_vars;
        $echo .= !$level
            ? sprintf("<ul class=\"nav %s cf %s level-%s\">", LEAPIN_Header::getMenuType(), self::$menu_name, $level)
            : sprintf("<ul class=\"sub-menu level-%s\">", $level);
        foreach ($multi_menu_items as $menu_id => $menu_item) {

            $object = $menu_item['main']->object;
            $object_id = $menu_item['main']->object_id;
            $has_children = array_key_exists('sub', $menu_item);


            $echo .= sprintf("<li class=\"menu-item %s %s\" data-%s='%s' data-object_type='%s' "
                , leapin_implode(" ", $menu_item['main']->classes)
                , $has_children ? "menu-item-has-children" : ""
                , $object
                , $object_id
                , $object
            );
            if ($object && in_array($object, array_keys($leapin_vars['taxonomies']))
                && $level < 2
                && !$has_children) {
                $echo .= "data-ajax='leapin_nav_taxonomy'";
                if ($level == 0) {
                    $echo .= " data-call_position='nav_level_0'";
                } else {
                    $echo .= " data-call_position='nav_level_1'";
                }
            } elseif (!$footer && $object && in_array($object, array_keys($leapin_vars['post_types']))
                && $level < 2
                && !$has_children) {
                $echo .= "data-ajax='leapin_nav_single'";
                if ($level == 0) {
                    $echo .= " data-call_position='nav_level_0'";
                } else {
                    $echo .= " data-call_position='nav_level_1'";
                }
            } elseif (!$footer && $object && $level == 2) {
                $echo .= "data-ajax='leapin_nav_thumbnail'";

            }
            $echo .= '>';

            $echo .= self::get_inner_tag($menu_item);

            if ($has_children) {
                $sub = $menu_item['sub'];
                self::get_menu_tag($echo, $footer, $sub, $limit, ++$level);
                $level--;
            }

            $echo .= "</li>";
        }
        if($level === 0){
            $echo .= "<span id='secondary-slide-line'></span>";
        }
        $echo .= "</ul>";

        return $echo;
    }

    private static function get_inner_tag($menu_item)
    {
        $a_tag = "<a href=\"%s\">%s</a>";
        $url = $menu_item['main']->url;
        $title = $menu_item['main']->title;
        return sprintf($a_tag, esc_attr($url), esc_html($title));
    }

    private static function create_menu_structure(&$multi_menu_items, $menu)
    {
        $id = $menu->ID;
        $parent_id = $menu->menu_item_parent;

        // parent doesn't exist
        if (!$parent_id):

            // add a tag into 1st level
            self::insert_menu_item_to_main($multi_menu_items[$id], $menu);

        else: // parent exists

            // search parent in top level menu items
            if (!self::add_menu_item_in_parent_menu($multi_menu_items, $parent_id, $menu)) {

                // couldn't find menu parent in top level menu items

                // search parent in second level menu items
                foreach ($multi_menu_items as &$second_level_menu_items) {
                    if (array_key_exists('sub', $second_level_menu_items)) {
                        self::add_menu_item_in_parent_menu($second_level_menu_items['sub'], $parent_id, $menu);
                    }
                }
            };
        endif; // check if parent exists

    }

    private static function add_menu_item_in_parent_menu(&$level_menu_items, $parent_id, &$menu)
    {

        foreach ($level_menu_items as $pk => &$pv) {
            // found parent menu
            if ($parent_id == $pk) {

                self::insert_menu_item_to_sub($pv, $menu);
                return true;
            }
        }
        return false;
    }

    private static function insert_menu_item_to_main(&$menu, $menu_item)
    {
        if (!is_array($menu)) {
            $menu = [];
        }
        $menu['main'] = $menu_item;
    }

    private static function insert_menu_item_to_sub(&$menu, $menu_item)
    {
        if (
        !array_key_exists('sub', $menu)) {
            $menu['sub'] = [];
        }
        self::insert_menu_item_to_main($menu['sub'][$menu_item->ID], $menu_item);
    }
}
