<?php

/**
 * Class LEAPIN_Single_Tags
 *
 * @author LeapIn Corp.
 * @since 1.0.0
 */
class LEAPIN_Single_Tags
{

    private static $user;
    public static $mods;

    public function __construct()
    {
        self::$mods = LEAPIN_Theme_Mod::get_instance();
        return $this;
    }

    public static function get_header_category_tag($id = false)
    {

        $term_id = leapin_get_yoast_primary_category_id($id);
        if ($term_id) {
            $cat = get_category($term_id);
            $cat_name = $cat->name;
            $cat_link = get_category_link($term_id);
        } elseif (($post_type = get_post_type()) != 'post') {
            $post_type = self::get_header_post_type_tag($post_type);
            $cat_name = $post_type['cat_name'];
            $cat_link = $post_type['cat_link'];
        }

        return isset($cat_name) ? sprintf('<a href="%s">%s</a>', $cat_link, $cat_name) : '';
    }

    public static function get_header_meta_tag()
    {
        $hide_date = leapin_mod_sr_only(LEAPIN_IDs::$leapin_hide_modified_date_below_title);
        $hide_category = leapin_mod_sr_only(LEAPIN_IDs::$leapin_hide_category_below_title);
        $rtn = '<div class="post-metas">';
        $rtn .= sprintf('%1$s',
            /* the time the post was published */
            '<time class="published entry-time sr-only" datetime="' . get_the_time('Y-m-d') . '" itemprop="datePublished">' . get_the_time(get_option('date_format')) . '</time>'
        );
        $rtn .= sprintf('<i class="far fa-calendar-alt updated-icon' . $hide_date . '"></i> %1$s',
            /* the time the post was published */
            '<time class="updated entry-time' . $hide_date . '" datetime="' . get_the_modified_date('Y-m-d') . '" itemprop="dateModified">' . get_the_time(get_option('date_format')) . '</time>'
        );
        $rtn .= sprintf('<i class="far fa-folder-open category-icon' . $hide_category . '"></i> %1$s',
            /* the time the post was published */
            '<span class="entry-category' . $hide_category . '" itemprop="">' . LEAPIN_Single_Tags::get_header_category_tag() . '</span>'
        );
        return $rtn . '</div>';
    }

    public static function is_home()
    {
        wp_reset_query();
        return is_front_page() || is_home();
    }

    private static function get_header_post_type_tag($post_type)
    {

        // If it is a custom post type display name and link
        if ($post_type != 'post') {

            $post_type_object = get_post_type_object($post_type);
            $post_type_archive = get_post_type_archive_link($post_type);
            $post_type_label = $post_type_object->labels->name;

        }

        return ['cat_name' => $post_type_label,
            'cat_link' => $post_type_archive];
    }

    public static function get_user_name()
    {
        self::$user = get_users()[0];
        return self::$user->display_name;
    }

    public static function get_avatar_url()
    {
        $user = self::$user;
        return get_avatar_url($user->ID);
    }

    public static function get_edit_user_link()
    {
        $user = self::$user;
        return get_edit_user_link($user->ID);
    }

    public static function get_user_url()
    {
        $user = self::$user;
        $user_url = $user->user_url;
        $url = !empty($user_url) ? $user_url : get_author_posts_url($user->ID);
        return $url;
    }

    public static function get_user_sns_urls()
    {
        $user = self::$user;
        $user_id = $user->ID;
        $google_plus = get_the_author_meta('googleplus', $user_id);
        $twitter = get_the_author_meta('twitter', $user_id);
        $facebook = get_the_author_meta('facebook', $user_id);
        return [
            'googleplus' => $google_plus ? $google_plus : ''
            , 'twitter' => $twitter ? $twitter : ''
            , 'facebook' => $facebook ? $facebook : ''
        ];
    }

    public static function get_org_sns_urls()
    {
        $twitter_name = self::$mods->get(LEAPIN_IDs::$leapin_publisher_twitter_name);
        $fb_url = self::$mods->get(LEAPIN_IDs::$leapin_publisher_fb_url);
        $gplus_url = self::$mods->get(LEAPIN_IDs::$leapin_publisher_gplus_url);
        $insta_url = self::$mods->get(LEAPIN_IDs::$leapin_publisher_insta_url);
        $linked_url = self::$mods->get(LEAPIN_IDs::$leapin_publisher_linkedin_url);
        $youtube_url = self::$mods->get(LEAPIN_IDs::$leapin_publisher_youtube_url);
        $website_url = self::$mods->get(LEAPIN_IDs::$leapin_publisher_website_url);
        return [
            'googleplus' => $gplus_url ? $gplus_url : false
            , 'twitter' => $twitter_name ? $twitter_name : false
            , 'facebook' => $fb_url ? $fb_url : false
            , 'linkedin' => $linked_url ? $linked_url : false
            , 'instagram' => $insta_url ? $insta_url : false
            , 'youtube' => $youtube_url ? $youtube_url : false
            , 'website' => $website_url ? $website_url : false
        ];
    }

    public static function get_sns_links($urls = false)
    {
        $echo = '';
        if (isset($urls) && is_array($urls)) {
            $tags = [
                'googleplus' => '<a class="icon-link" href="%s" rel="nofollow" target="_blank"><i class="icomoon icon-googleplus"></i></a>'
                , 'twitter' => '<a class="icon-link" href="https://twitter.com/%s" rel="nofollow" target="_blank"><i class="icomoon icon-twitter"></i></a>'
                , 'facebook' => '<a class="icon-link" href="%s" rel="nofollow" target="_blank"><i class="icomoon icon-facebook"></i></a>'
                , 'linkedin' => '<a class="icon-link" href="%s" rel="nofollow" target="_blank"><i class="icomoon icon-linkedin"></i></a>'
                , 'instagram' => '<a class="icon-link" href="%s" rel="nofollow" target="_blank"><i class="icomoon icon-instagram"></i></a>'
                , 'youtube' => '<a class="icon-link" href="%s" rel="nofollow" target="_blank"><i class="icomoon icon-youtube"></i></a>'
                , 'website' => '<a class="icon-link sr-only" href="%s" rel="nofollow" target="_blank">website</a>'
            ];
            foreach ($urls as $key => $url) {
                if (!empty($url)) {
                    $echo .= sprintf($tags[$key], $url);
                }
            }
        }
        return $echo;
    }

    public static function get_user_sns_link_tags()
    {
        $urls = self::get_user_sns_urls();
        $echo = self::get_sns_links($urls);

        return $echo;
    }

    public static function get_user_description()
    {
        $user = self::$user;
        $desc = $user->description;
        return $desc;
    }

    public static function the_admin_meta()
    {
        if (is_user_logged_in()):
            ?>
            <p class="admin-meta cf">
            <?php if (LEAPIN_AMP_Tags::has_amp_page()):
            $development = LEAPIN_DEV ? '#development=1' : '';
            $amp_view_url = LEAPIN_AMP_Tags::is_amp() ? leapin_get_permalink() : LEAPIN_AMP_Tags::get_amp_permalink() . $development; ?>
            <span class="amp-view"><i class="icomoon icon-amp"></i><a
                        href="<?php echo $amp_view_url; ?>"><?php _e('AMP', 'pjax-blog') ?></a></span>
            <span class="amp-test"><i class="icomoon icon-amp"></i><a
                        href="<?php echo LEAPIN_AMP_Tags::get_amp_test_tool_url(LEAPIN_AMP_Tags::get_amp_permalink()); ?>"
                        target="_blank"><?php _e('Validate', 'pjax-blog') ?></a></span>
        <?php
        endif;
            echo LEAPIN_Single_Tags::get_edit_link();
            echo '</p>';
        endif;
    }

    public static function get_edit_link()
    {
        ob_start();
        edit_post_link(__('Edit', 'pjax-blog'), '<span class="edit"><i class="fas fa-edit"></i>', '</span>');
        return ob_get_clean();
    }

    public static function get_author_section($hide_author_section = '')
    {
        $user_name = LEAPIN_Single_Tags::get_user_name();
        $user_link = LEAPIN_Single_Tags::get_user_url();
        $avatar_url = LEAPIN_Single_Tags::get_avatar_url();
        $user_edit_url = LEAPIN_Single_Tags::get_edit_user_link();
        ?>
        <div class="row entry-author author cf<?php echo $hide_author_section ?>" itemprop="author" itemscope
             itemtype="https://schema.org/Person">
            <div class="author__avator">
                <a class="avator" href="<?php echo $user_link; ?>"
                   title="<?php _e('View detail about author', 'pjax-blog'); ?>">
                    <img class="author__img-lg" src="<?php echo $avatar_url; ?>"
                         alt="<?php echo $user_name; ?>"/>
                </a>
            </div>
            <div class="author__detail">
                <?php $author_edit_label = __('Edit', 'pjax-blog'); ?>
                <a class="author__name" rel="author" itemprop="url" href="<?php echo $user_link; ?>"
                   title="<?php _e('View detail about author', 'pjax-blog'); ?>">
                    <span itemprop="name"><?php echo $user_name; ?></span>
                </a>
                <?php if (is_user_logged_in()): ?>
                    <a class="author__editing-page" href="<?php echo $user_edit_url; ?>" target="_blank"
                       title="<?php echo $author_edit_label; ?>">
                        <span itemprop="name"><?php echo $author_edit_label; ?></span>
                    </a>
                <?php endif; ?>
                <div class="author__contact">
                    <?php echo LEAPIN_Single_Tags::get_user_sns_link_tags(); ?>
                </div>
        <p class="author__description">
            <?php echo LEAPIN_Single_Tags::get_user_description(); ?>
        </p>
        </div>
        </div>
        <?php
    }

    public static function the_publisher_markup()
    {
        $p_name = self::$mods->get(LEAPIN_IDs::$leapin_publisher_name, false);
        $p_logo = self::$mods->get(LEAPIN_IDs::$leapin_publisher_logo, false);
        $amp_logo = self::$mods->get(LEAPIN_IDs::$leapin_amp_logo, false);
        if (LEAPIN_AMP_Tags::is_amp() && !empty($amp_logo)) {
            $p_logo = $amp_logo;
        }
        $p_logo_width = $p_logo_height = '';
        if (!empty($p_logo) && !is_customize_preview()) {
            $logo_info = leapin_get_image_width_and_height($p_logo);
            $p_logo_width = $logo_info['width'];
            $p_logo_height = $logo_info['height'];
        }
        ?>
        <span class="sr-only" itemprop="publisher" itemscope itemtype="https://schema.org/Organization">
          <meta itemprop="name" content="<?php echo $p_name ?>">
          <span itemprop="logo" itemscope itemtype="https://schema.org/ImageObject">
              <?php if (isset($logo_info)): ?>
                  <meta itemprop="url" content="<?php echo $p_logo; ?>">
                  <meta itemprop="width" content="<?php echo $p_logo_width; ?>">
                  <meta itemprop="height" content="<?php echo $p_logo_height; ?>">
              <?php endif; ?>
          </span>
        </span>
        <?php
    }

    public static function is_sns_button_enable()
    {
        return !get_post_meta(get_the_ID(), 'is_nosns', true);
    }

    public static function is_stop_autop()
    {
        return get_post_meta(get_the_ID(), 'stop_autop', true);
    }

    public static function get_the_title()
    {
        echo get_the_title() ?: __('No Title', 'pjax-blog');
    }

    /**
     * Get Header HTML
     *
     * @param string $position
     * in_article : call from the top of article div
     * in_head: call above the article div
     * @return string header html
     */
    public static function get_header($position = 'in_article')
    {
        $header_style = self::get_header_style();
        $header_entire = true;
        $header_image_display = true;
        $header_meta = '';
        $header_admin_meta = true;

        // is single
        if(!is_singular()){
            return;
        }

        // position is in article
        if($position == 'in_article'){
            if($header_style == 'default'){
            }else if($header_style == 'fullwidth' || $header_style == 'noheader'){
                $header_image_display = false;
                $header_meta = ' sr-only';
                $header_admin_meta = ' sr-only';
            }else if($header_style == 'nofeatureimage'){
                $header_image_display = false;
            }
        }
        // position is in head
        if($position == 'in_head'){
            $header_admin_meta = false;
            if($header_style != 'fullwidth'){
                $header_entire = false;
            }
        }

        ob_start();
        if($header_entire):
        ?>
        <header class="article-header entry-header <?php echo $header_style ?>">
            <figure class="image-container" itemprop="image" itemscope itemtype="https://schema.org/ImageObject">
                <?php
                $thumbnail_size = LEAPIN_AMP_Tags::is_amp() ? 'leapin-medium' : 'large';
                $img = leapin_get_eyecatch_image($thumbnail_size);

                if ($header_image_display):

                    if (!LEAPIN_AMP_Tags::is_amp()) {
                        add_filter('leapin_load_css_on_each_pjax', function ($css) use ($img) {
                            return $css . '.main-thumbnail{background-image: url("' . $img[0] . '");}';
                        });
                    }
                    ?>

                    <div class="main-thumbnail bg-img"></div>
                <?php endif; ?>
                <meta itemprop="url" content="<?php echo $img[0]; ?>">
                <meta itemprop="width" content="<?php echo $img[1]; ?>">
                <meta itemprop="height" content="<?php echo $img[2]; ?>">
            </figure>
            <div class="title-container<?php echo $header_meta; ?>">
                <h1 class="entry-title single-title" itemprop="headline" rel="bookmark"><?php the_title(); ?></h1>
            </div>
            <meta itemprop="mainEntityOfPage" content="<?php the_permalink(); ?>">
            <?php if (!is_page()): ?>
                <div class="byline entry-meta vcard<?php echo $header_meta; ?>">
                    <?php echo LEAPIN_Single_Tags::get_header_meta_tag(); ?>
                    <?php $hide_author = leapin_mod_sr_only(LEAPIN_IDs::$leapin_hide_author_name_below_title); ?>
                    <div class="author<?php echo $hide_author ?>">
                        <?php /* the author of the post */ ?>
                        <?php
                        $user_name = LEAPIN_Single_Tags::get_user_name();
                        $user_link = LEAPIN_Single_Tags::get_user_url();
                        $avatar_url = LEAPIN_Single_Tags::get_avatar_url();
                        ?>
                        <span class="avator"><img class="author__img-sm" src="<?php echo $avatar_url; ?>"/></span>
                        <span class="by-who"><a href="<?php echo $user_link; ?>"><?php echo $user_name; ?></a></span>
                    </div>
                </div>
            <?php endif; ?>
            <?php
            if($header_admin_meta):
                LEAPIN_Single_Tags::the_admin_meta();
            endif;
            ?>

        </header> <?php // end article header
        ?>
        <?php
        endif;
        return ob_get_clean();
    }

    public static function get_header_style()
    {

        $header_style = get_post_meta(get_the_ID(), 'leapin_header_style', true);
        if(empty($header_style)){
            $header_style = self::$mods->get(LEAPIN_IDs::$leapin_single_header_style, LEAPIN_Theme_Mod::$default_leapin_single_header_style);
        }

        return $header_style;
    }
}

new LEAPIN_Single_Tags();