<?php
/**
 * Class LEAPIN_Single
 *
 * @author LeapIn Corp.
 * @since 1.0.0
 */
class LEAPIN_Single {

	public function __construct() {

	    require_once('class-leapin-single-tags.php');
		$this->registerActionHooks();

		return $this;
	}

	public function registerActionHooks() {

		add_action('customize_register', array($this, 'customizer'));
        add_action('admin_menu', array($this, 'addMetaBoxes'));
        add_action('save_post', array($this, 'save_page_custom_data'));
        add_action('save_post', array($this, 'save_amp_custom_data'));
        add_action('save_post', array($this, 'save_sns_custom_data'));
        add_action('save_post', array($this, 'save_read_more_label_custom_data'));

        return $this;
	}

	public function customizer($wp_customize) {

		$this->registerCustomizerSettings('single', $wp_customize);

		return;
	}

	public function registerCustomizerSettings($file_handle = '', $wp_customize) {

		require_once get_template_directory() . '/inc/single/customizer/' . sanitize_title($file_handle) . '.php';

		return $this;
	}

	public function addMetaBoxes() {
        // set page layout
        add_meta_box('leapin_page_setting_in_page', __('Page Layout', 'pjax-blog'), array($this, 'view_page_custom_box'), 'post', 'side');
        add_meta_box('leapin_page_setting_in_page', __('Page Layout', 'pjax-blog'), array($this, 'view_page_custom_box'), 'page', 'side');
        add_meta_box('leapin_page_setting_in_page', __('Page Layout', 'pjax-blog'), array($this, 'view_page_custom_box'), 'custom_post_type', 'side');


        if (LEAPIN_AMP_Tags::is_amp_active()) {
            // set AMP
            add_meta_box('leapin_amp_setting_in_page', __('AMP', 'pjax-blog'), array($this, 'view_amp_custom_box'), 'post', 'side');
            add_meta_box('leapin_amp_setting_in_page', __('AMP', 'pjax-blog'), array($this, 'view_amp_custom_box'), 'page', 'side');
            add_meta_box('leapin_amp_setting_in_page', __('AMP', 'pjax-blog'), array($this, 'view_amp_custom_box'), 'custom_post_type', 'side');
        }
        // set sns visibility
        add_meta_box('leapin_sns_setting_in_page', __('SNS Button Visibility', 'pjax-blog'), array($this, 'view_sns_custom_box'), 'post', 'side');
        add_meta_box('leapin_sns_setting_in_page', __('SNS Button Visibility', 'pjax-blog'), array($this, 'view_sns_custom_box'), 'page', 'side');
        add_meta_box('leapin_sns_setting_in_page', __('SNS Button Visibility', 'pjax-blog'), array($this, 'view_sns_custom_box'), 'custom_post_type', 'side');
        // set blog post button label visibility
        add_meta_box('leapin_read_more_label_setting_in_page', __('Button Label', 'pjax-blog'), array($this, 'view_read_more_label_custom_box'), 'post', 'side');
        add_meta_box('leapin_read_more_label_setting_in_page', __('Button Label', 'pjax-blog'), array($this, 'view_read_more_label_custom_box'), 'page', 'side');
        add_meta_box('leapin_read_more_label_setting_in_page', __('Button Label', 'pjax-blog'), array($this, 'view_read_more_label_custom_box'), 'custom_post_type', 'side');

        return $this;
    }



    public function view_page_custom_box(){
        $leapin_layouts_single = get_post_meta(get_the_ID(),'leapin_layouts_single', true);

        echo '<label>'.__( 'Select Layout:', 'pjax-blog' ).'</label><br>';
        echo '<select name="leapin_layouts_single">';
        echo '<option value="default"';
        if( $leapin_layouts_single == 'default' ){echo ' selected';}
        echo '>--</option>';
        // 1 Column
        echo '<option value="col-1_column"';
        if( $leapin_layouts_single == 'col-1_column' ){echo ' selected';}
        echo '>'.__('Full Page Layout','pjax-blog').'</option>';
        // 1 Column with full width
        echo '<option value="col-1_column_full_width"';
        if( $leapin_layouts_single == 'col-1_column_full_width' ){echo ' selected';}
        echo '>'.__('Full Page Layout (Full Width)','pjax-blog').'</option>';
        echo '</select>';
        echo '<p class="howto">'.__( 'Select the layout of this post.', 'pjax-blog' ).'</p>';
    }

    public function view_amp_custom_box(){
        $is_noamp = get_post_meta(get_the_ID(),'is_noamp', true);
        echo '<label><input type="checkbox" name="is_noamp"';
        if( $is_noamp ){echo " checked";}
        echo '>'.__( 'Deactivate AMP', 'pjax-blog' ).'</label>';
        echo '<p class="howto" style="margin-top:0;">'.__( 'Recommend to check this when the page containing scripts such as affiliate conversion script.', 'pjax-blog' ).'</p>';

    }

    public function view_read_more_label_custom_box(){
        $default = LEAPIN_Theme_Mod::get_instance()->get(LEAPIN_IDs::$leapin_widget_post_read_more_label, LEAPIN_Theme_Mod::$default_leapin_widget_post_read_more_label);
        $read_more_label = get_post_meta(get_the_ID(),'read_more_label', true);
        echo '<p class="howto" style="margin-top:0;">'.__( 'It\'s used for button label in [Pjax Blog] Blog Posts widget.', 'pjax-blog' ).'</p>';
        echo '<label><input type="text" name="read_more_label" value="'. ($read_more_label ? $read_more_label : $default) .'"></label>';
    }

    public function view_sns_custom_box(){
        $is_nosns = get_post_meta(get_the_ID(),'is_nosns', true);
        echo '<label><input type="checkbox" name="is_nosns"';
        if( $is_nosns ){echo " checked";}
        echo '>'.__( 'Hide SNS Button Groups', 'pjax-blog' ).'</label>';
        echo '<p class="howto" style="margin-top:0;">'.__( 'Hide SNS button groups in sidebar and below single content.', 'pjax-blog' ).'</p>';

    }

    public function save_page_custom_data(){
        $id = get_the_ID();

        if ( isset( $_POST['leapin_layouts_single'] ) ){
            $leapin_layouts_single = $_POST['leapin_layouts_single'];
            $leapin_layouts_single_key = 'leapin_layouts_single';
            update_post_meta($id, $leapin_layouts_single_key, $leapin_layouts_single);
        }
    }

    public function save_amp_custom_data(){
        $id = get_the_ID();

        $is_noamp = null;
        if ( isset( $_POST['is_noamp'] ) ){
            $is_noamp = $_POST['is_noamp'];
        }
        $is_noamp_key = 'is_noamp';
        update_post_meta($id, $is_noamp_key, $is_noamp);
    }

    public function save_read_more_label_custom_data(){
        $id = get_the_ID();

        $read_more_label = null;
        if ( isset( $_POST['read_more_label'] ) ){
            $read_more_label = $_POST['read_more_label'];
        }
        $read_more_label_key = 'read_more_label';
        update_post_meta($id, $read_more_label_key, sanitize_text_field($read_more_label));
    }

    public function save_sns_custom_data(){
        $id = get_the_ID();

        $is_nosns = null;
        if ( isset( $_POST['is_nosns'] ) ){
            $is_nosns = $_POST['is_nosns'];
        }
        $is_nosns_key = 'is_nosns';
        update_post_meta($id, $is_nosns_key, $is_nosns);
    }
}
$tpsingle = new LEAPIN_Single();
