<?php
/**
 * Font Options
 *
 * @author LeapIn Corp.
 * @since 1.0.0
 */

/**
 * Heading Fonts.
 */
// Load the file that implements 'leapin_get_google_fonts' function.
require_once get_template_directory() . '/inc/typography/customizer/font-library.php';
$font_stack_collection = leapin_get_font_stack_collection();

$panel = 'leapin_settings';
$section = 'leapin_typography_section';
LEAPIN_IDs::initPriority();

$wp_customize->add_section($section_id = $section,
    array(
        'title' => __('Typography', 'pjax-blog'),
        'description' => '<em>' . __('Select desired font combination for your website.', 'pjax-blog') . '</em>',
        'panel' => $panel,
        'priority' => 80,
    )
);

/**
 * Default Font Stack
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_typography_font_stack,
    array(
        'type' => 'theme_mod', // or 'option'
        'capability' => 'manage_options',
        'default' => LEAPIN_Theme_Mod::$default_leapin_typography_font_stack,
        'transport' => LEAPIN_IDs::$refresh,
        'sanitize_callback' => 'leapin_sanitize_text'
    )
);

$wp_customize->add_control(LEAPIN_IDs::$leapin_typography_font_stack,
    array(
        'label' => __('Default Font Stack (System Font)', 'pjax-blog'),
        'type' => 'select',
        'description' => __('Select the desired font to be applied in Entire Page.', 'pjax-blog'),
        'section' => $section,
        'choices' => $font_stack_collection,
        'priority' => LEAPIN_IDs::getPriority()
    )
);

/**
 * RTL Setting
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_typography_rtl, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => 'no',
    'transport' => LEAPIN_IDs::$refresh,
    'sanitize_callback' => 'leapin_sanitize_text',
));

$wp_customize->add_control(LEAPIN_IDs::$leapin_typography_rtl, array(
    'type' => 'radio',
    'label' => __('Direction:', 'pjax-blog'),
    'section' => $section,
    'choices' => array(
        'no' => 'Left to Right (Default)',
        'yes' => 'Right to Left (RTL Mode)',
    ),
    'priority' => LEAPIN_IDs::getPriority()
));
/**
 * Text Color
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_typography_text_color, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => '',
    'transport' => LEAPIN_IDs::$postMessage,
    'sanitize_callback' => 'leapin_sanitize_rgba_color'
));
$wp_customize->add_control(new LEAPIN_Customize_Alpha_Color_Control($wp_customize, LEAPIN_IDs::$leapin_typography_text_color . '_control', array(
    'settings' => LEAPIN_IDs::$leapin_typography_text_color,
    'label' => __('Text Color', 'pjax-blog'),
    'section' => $section,
    'show_opacity' => true,
    'priority' => LEAPIN_IDs::getPriority()
)));


/**
 * Link Default Color
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_typography_link_color, array(
    'type' => 'theme_mod',
    'capability' => 'manage_options',
    'default' => '',
    'transport' => LEAPIN_IDs::$refresh,
    'sanitize_callback' => 'leapin_sanitize_rgba_color',
));
$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, LEAPIN_IDs::$leapin_typography_link_color, array(
    'settings' => LEAPIN_IDs::$leapin_typography_link_color,
    'label' => __('Link Default Color', 'pjax-blog'),
    'section' => $section,
    'priority' => LEAPIN_IDs::getPriority()
)));

/**
 * Link Hover Color
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_typography_link_color_hover, array(
    'type' => 'theme_mod',
    'capability' => 'manage_options',
    'default' => '',
    'transport' => LEAPIN_IDs::$refresh,
    'sanitize_callback' => 'leapin_sanitize_rgba_color',
));
$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, LEAPIN_IDs::$leapin_typography_link_color_hover, array(
    'settings' => LEAPIN_IDs::$leapin_typography_link_color_hover,
    'label' => __('Link Hover Color', 'pjax-blog'),
    'section' => $section,
    'priority' => LEAPIN_IDs::getPriority()
)));