/**
 * Page transition Module
 *
 * @type {{nextPage}}
 */
var LEAPIN_TRANS = (function ($) {

    var isAnimating = false,
        endCurrPage = false,
        endNextPage = false,
        animEndEventNames = {
            'WebkitAnimation': 'webkitAnimationEnd',
            'OAnimation': 'oAnimationEnd',
            'msAnimation': 'MSAnimationEnd',
            'animation': 'animationend'
        },
        // animation end event name
        animEndEventName = animEndEventNames[Modernizr.prefixed('animation')],
        // support css animations
        support = Modernizr.cssanimations;

    function nextPage(animation, barba, cb) {

        if (isAnimating) {
            return false;
        }

        isAnimating = true;

        var $currPage = $(barba.oldContainer);
        var $nextPage = $(barba.newContainer)

        $nextPage.css({visibility: 'visible'});

        if (LEAPIN_CORE.is_pro()) {
            var clsObj = LEAPIN_PRO.get_move_page_transition(animation);
        } else {
            var clsObj = LEAPIN_CORE.get_move_page_transition(animation);
        }
        var inClass = clsObj.inClass;
        var outClass = clsObj.outClass;

        $currPage.addClass(outClass).on(animEndEventName, function () {
            $currPage.off(animEndEventName);
            endCurrPage = true;
            if (endNextPage) {
                onEndAnimation($currPage, $nextPage, barba, cb);
            }
        });

        $nextPage.addClass(inClass).on(animEndEventName, function () {
            $nextPage.off(animEndEventName);
            endNextPage = true;
            if (endCurrPage) {
                onEndAnimation($currPage, $nextPage, barba, cb);
            }
        });

        if (!support) {
            onEndAnimation($currPage, $nextPage, barba, cb);
        }

    }

    function onEndAnimation($outpage, $inpage, barba, callback) {
        endCurrPage = false;
        endNextPage = false;
        isAnimating = false;
        barba.done();
        callback($outpage, $inpage, barba);
    }

    return {nextPage: nextPage};

})(jQuery);